breastcancerwisconsin: Wisconsin breast cancer data

breastcancerwisconsinR Documentation

Wisconsin breast cancer data

Description

A binary classification dataset for breast cancer diagnosis from cytology measurements.

Usage

breastcancerwisconsin

Format

A data frame with 699 rows and 10 variables:

clump_thickness

Clump thickness score.

uniformity_cell_size

Uniformity of cell size score.

uniformity_cell_shape

Uniformity of cell shape score.

marginal_adhesion

Marginal adhesion score.

single_epithelial_cell_size

Single epithelial cell size score.

bare_nuclei

Bare nuclei score.

bland_chromatin

Bland chromatin score.

normal_nucleoli

Normal nucleoli score.

mitoses

Mitoses score.

class

Diagnostic class (2 = benign, 4 = malignant).

Wisconsin Breast Cancer Database from University of Wisconsin Hospitals, distributed through the UCI Machine Learning Repository.

Examples

str(funcml::breastcancerwisconsin)
table(funcml::breastcancerwisconsin$class)

funcml documentation built on Aug. 22, 2026, 5:08 p.m.