cigsmoke: Youth tobacco survey data

cigsmokeR Documentation

Youth tobacco survey data

Description

A classification-oriented survey dataset on smoking exposure, tobacco use, and tobacco-related environments among youth respondents.

Usage

cigsmoke

Format

A data frame with 3,915 rows and 27 variables:

final_wgt

Survey final weight.

age

Age group.

gender

Gender.

income

Personal spending money category.

parent_work

Parental work status.

father_education

Father's education level.

mother_education

Mother's education level.

living_env

Living environment.

age_first_cig

Age at first cigarette.

cigar_use

Cigar use indicator.

noncig_use

Non-cigarette tobacco use indicator.

smokeless_use

Smokeless tobacco use indicator.

parent_smoke

Parental smoking exposure.

friends_smoke

Friends' smoking exposure.

home_shs

Secondhand smoke exposure at home.

outside_shs

Secondhand smoke exposure outside the home.

indoor_ban

Indoor smoking ban indicator.

outdoor_ban

Outdoor smoking ban indicator.

antitobacco_media

Exposure to antitobacco media.

antitobacco_school

Exposure to school antitobacco education.

tobacco_media

Exposure to tobacco media.

offer_freetobacco

Whether free tobacco was offered.

own_items

Ownership of tobacco-branded items.

knowledge_harm

Knowledge that tobacco is harmful.

e_cig

Electronic cigarette use indicator.

stratum

Survey stratum identifier.

psu

Primary sampling unit identifier.

Details

Column names were standardized to snake_case when packaging the data.

Morocco Global Youth Tobacco Survey public-use survey data.

References

Kim N, Loh WY, McCarthy DE (2021). Machine learning models of tobacco susceptibility and current use among adolescents from 97 countries in the Global Youth Tobacco Survey, 2013-2017. PLOS Global Public Health, 1(12), e0000060. doi:10.1371/journal.pgph.0000060.

Examples

str(funcml::cigsmoke)
table(funcml::cigsmoke$e_cig)

funcml documentation built on Aug. 22, 2026, 5:08 p.m.