interpret-calibration-methods: Calibration result methods.

interpret-calibration-methodsR Documentation

Calibration result methods.

Description

These methods provide the standard print(), summary(), and plot() interfaces for funcml_calibration objects returned by interpret(method = "calibration").

Usage

## S3 method for class 'funcml_calibration'
plot(x, style = c("curve", "histogram"), ...)

## S3 method for class 'funcml_calibration'
print(x, digits = 4L, ...)

## S3 method for class 'funcml_calibration'
summary(object, digits = 4L, ...)

Arguments

x

A funcml_calibration object.

style

Plot style: "curve" or "histogram".

...

Additional arguments passed to the underlying method.

digits

Number of digits numeric columns are rounded to when printed.

object

A funcml_calibration object.

Value

plot() returns a ggplot2 object. print() returns the input object invisibly. summary() returns a list with calibration curve and summary diagnostics invisibly.

Examples

fit_obj <- fit(mpg > 20 ~ wt + hp + disp, data = mtcars, model = "glm")
cal <- interpret(
  fit = fit_obj,
  data = mtcars,
  method = "calibration"
)
print(cal)
summary(cal)
plot(cal)

funcml documentation built on Aug. 22, 2026, 5:08 p.m.