ketapain: Ketamine pain management data

ketapainR Documentation

Ketamine pain management data

Description

A regression dataset on ketamine dosing, treatment characteristics, cost, quality-adjusted life years, and administration mode.

Usage

ketapain

Format

A data frame with 184 rows and 11 variables:

patient_id

Patient identifier.

sexe

Recorded sex.

age

Patient age in years.

av_dose

Average dose.

level_dose

Dose level category.

cum_dose

Cumulative dose.

cum_days

Cumulative treatment days.

perfusion

Perfusion duration.

cost

Treatment cost.

qaly

Quality-adjusted life years.

mode

Administration mode.

Details

Column names were standardized to snake_case when packaging the data.

Original ketamine pain management dataset distributed with the project materials.

Examples

str(funcml::ketapain)
summary(funcml::ketapain$qaly)

funcml documentation built on Aug. 22, 2026, 5:08 p.m.