learners: Available learners.

View source: R/fit.R

learnersR Documentation

Available learners.

Description

learners() returns the registry keys accepted by fit(). Task support is: regression and classification: glm, rpart, glmnet, ranger, nnet, mlp, densemlp, e1071_svm, randomForest, gbm, kknn, ctree, cforest, lightgbm, xgboost, stacking, superlearner; regression plus binary classification: gam, bart, earth; classification only: C50, naivebayes, fda, lda, qda; binary classification only: adaboost; regression only: pls.

Usage

learners()

Details

The learner engine packages are installed with funcml, so the advertised registry is intended to be available after a standard installation.

Value

Character vector of learner ids.

Examples

learners()

funcml documentation built on Aug. 22, 2026, 5:08 p.m.