mammography: Mammography calcification data

mammographyR Documentation

Mammography calcification data

Description

A binary classification dataset for detection of mammographic microcalcifications.

Usage

mammography

Format

A data frame with 11,183 rows and 7 variables:

attr1

Numeric imaging-derived predictor 1.

attr2

Numeric imaging-derived predictor 2.

attr3

Numeric imaging-derived predictor 3.

attr4

Numeric imaging-derived predictor 4.

attr5

Numeric imaging-derived predictor 5.

attr6

Numeric imaging-derived predictor 6.

class

Calcification class (⁠\"-1\"⁠ or ⁠\"1\"⁠).

Woods K, Doss C, Bowyer K, Solka J, Priebe C, Kegelmeyer P (1993). Comparative evaluation of pattern recognition techniques for detection of microcalcifications in mammography.

Examples

str(funcml::mammography)
table(funcml::mammography$class)

funcml documentation built on Aug. 22, 2026, 5:08 p.m.