| breastcancerwisconsin | R Documentation |
A binary classification dataset for breast cancer diagnosis from cytology measurements.
breastcancerwisconsin
A data frame with 699 rows and 10 variables:
Clump thickness score.
Uniformity of cell size score.
Uniformity of cell shape score.
Marginal adhesion score.
Single epithelial cell size score.
Bare nuclei score.
Bland chromatin score.
Normal nucleoli score.
Mitoses score.
Diagnostic class (2 = benign, 4 = malignant).
Wisconsin Breast Cancer Database from University of Wisconsin Hospitals, distributed through the UCI Machine Learning Repository.
str(funcml::breastcancerwisconsin)
table(funcml::breastcancerwisconsin$class)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.