| ketapain | R Documentation |
A regression dataset on ketamine dosing, treatment characteristics, cost, quality-adjusted life years, and administration mode.
ketapain
A data frame with 184 rows and 11 variables:
Patient identifier.
Recorded sex.
Patient age in years.
Average dose.
Dose level category.
Cumulative dose.
Cumulative treatment days.
Perfusion duration.
Treatment cost.
Quality-adjusted life years.
Administration mode.
Column names were standardized to snake_case when packaging the data.
Original ketamine pain management dataset distributed with the project materials.
str(funcml::ketapain)
summary(funcml::ketapain$qaly)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.