| learners | R Documentation |
learners() returns the registry keys accepted by fit(). Task support is:
regression and classification: glm, rpart, glmnet, ranger, nnet, mlp,
densemlp, e1071_svm, randomForest, gbm, kknn, ctree, cforest,
lightgbm, xgboost, stacking, superlearner;
regression plus binary classification: gam, bart, earth;
classification only: C50, naivebayes, fda, lda, qda;
binary classification only: adaboost;
regression only: pls.
learners()
The learner engine packages are installed with funcml, so the advertised
registry is intended to be available after a standard installation.
Character vector of learner ids.
learners()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.