| mammography | R Documentation |
A binary classification dataset for detection of mammographic microcalcifications.
mammography
A data frame with 11,183 rows and 7 variables:
Numeric imaging-derived predictor 1.
Numeric imaging-derived predictor 2.
Numeric imaging-derived predictor 3.
Numeric imaging-derived predictor 4.
Numeric imaging-derived predictor 5.
Numeric imaging-derived predictor 6.
Calcification class (\"-1\" or \"1\").
Woods K, Doss C, Bowyer K, Solka J, Priebe C, Kegelmeyer P (1993). Comparative evaluation of pattern recognition techniques for detection of microcalcifications in mammography.
str(funcml::mammography)
table(funcml::mammography$class)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.